
============  ===============  ======  ========  =======  ===============  ======  =========================
name          value            unit    type      valid    default          code    description
============  ===============  ======  ========  =======  ===============  ======  =========================
description   UNKNOWN                  string    None     UNKNOWN          B       Description of this produ
                                                                                   ct
type          Product                  string    None     Product          B       Product Type identificati
                                                                                   on. Name of class or CARD
                                                                                   .
creator       UNKNOWN                  string    None     UNKNOWN          B       Generator of this product
                                                                                   .
creationDate  1958-01-01               finetime  None     1958-01-01               Creation date of this pro
              00:00:00.000000                             00:00:00.000000          duct
              0                                           0
rootCause     UNKNOWN                  string    None     UNKNOWN          B       Reason of this run of pip
                                                                                   eline.
version       0.8                      string    None     0.8              B       Version of product
FORMATV       1.5.0.9                  string    None     1.5.0.9          B       Version of product schema
                                                                                    and revision
startDate     1958-01-01               finetime  None     1958-01-01               Nominal start time  of th
              00:00:00.000000                             00:00:00.000000          is product.
              0                                           0
endDate       1958-01-01               finetime  None     1958-01-01               Nominal end time  of this
              00:00:00.000000                             00:00:00.000000           product.
              0                                           0
instrument    UNKNOWN                  string    None     UNKNOWN          B       Instrument that generated
                                                                                    data of this product
modelName     UNKNOWN                  string    None     UNKNOWN          B       Model name of the instrum
                                                                                   ent of this product
mission       _AGS                     string    None     _AGS             B       Name of the mission.
============  ===============  ======  ========  =======  ===============  ======  =========================
MetaData-listeners = ListnerSet{}